Learn R Programming

LMMELSM (version 0.2.0)

.magicsep: Convert char vector to columns.

Description

Converts a character vector int columns.

Usage

.magicsep(charvec, labs, types = NULL, sep = "MAGICSEP")

Value

data.frame

Arguments

charvec

Character vector. Characters to separate into columns.

labs

Character vector. Labels for the columns.

types

List (Default: All characters). List (in order) of extracted types.

sep

String (Default: "MAGICSEP").

Author

Stephen R. Martin

Details

A wrapper around strcapture. Given "a_MAGICSEP_b", returns a vector of "a_" and "_b". Useful for converting a multiple-parameter string into columns of parameters. User can give column names in labs, and types of each extracted component as a list in types. User can customize sep, but by default assumes MAGICSEP.