Learn R Programming

LMMELSM (version 0.2.0)

coef.lmmelsm: Extract group-specific coefficients.

Description

Coef method for lmmelsm objects.

Usage

# S3 method for lmmelsm
coef(object, prob = 0.95, summarize = TRUE, ...)

Value

List of summaries (if summarize is TRUE), or list of MCMC samples.

Arguments

object

lmmelsm object.

prob

Numeric (Default: .95). Amount of probability mass contained in the credible interval.

summarize

Logical (Default: TRUE). Whether to return posterior summaries (TRUE) or MCMC samples (FALSE).

...

Not used.

Author

Stephen R Martin

Details

Extracts all group-specific coefficients from lmmelsm object. Note that this is different from ranef. Whereas ranef extracts the zero-centered random effects, coef extracts the group-specific effects, defined as the sum of the fixed effect and random effect.