Learn R Programming

LMMELSM (version 0.2.0)

fitted.lmmelsm: Extracted model fitted variates.

Description

Extract model fitted variates.

Usage

# S3 method for lmmelsm
fitted(object, prob = 0.95, summarize = TRUE, ...)

Value

List of eta and eta_logsd. If summarize is TRUE, then the list contains formatted summary tables. If FALSE, then the list contains MCMC samples for all variables.

Arguments

object

lmmelsm object.

prob

Numeric (Default: .95). Amount of probability mass contained in the credible interval.

summarize

Logical (Default: TRUE). Whether to return posterior summaries (TRUE) or MCMC samples (FALSE).

...

Not used.

Author

Stephen Martin

Details

Extracts model fitted variates. When a latent MMELSM, these are the latent score expectations and log standard deviations. When an observed MMELSM, these are the observed score expectations and log standard deviations.