Learn R Programming

LMMELSM (version 0.2.0)

ranef.lmmelsm: Extract random effects.

Description

Ranef method for lmmelsm objects.

Usage

# S3 method for lmmelsm
ranef(object, prob = 0.95, summarize = TRUE, ...)

Value

List of ranef summaries (random_mu_intercept, random_logsd_intercept, random_mu_coef, and random_logsd_coef), or samples (if summarize = FALSE).

Arguments

object

lmmelsm object.

prob

Numeric (Default: .95). Amount of probability mass contained in the credible interval.

summarize

Logical (Default: TRUE). Whether to return posterior summaries (TRUE) or MCMC samples (FALSE).

...

Not used.

Author

Stephen R. Martin

Details

Extracts the random effects from the lmmelsm object. Note that this is different from the random coefficients. E.g., if \(\beta_{0i} = \beta_0 + u_{0i}\), then coef extracts \(\beta_{0i}\) and ranef extracts \(u_{0i}\).