Converts a character vector int columns.
.magicsep(charvec, labs, types = NULL, sep = "MAGICSEP")data.frame
Character vector. Characters to separate into columns.
Character vector. Labels for the columns.
List (Default: All characters). List (in order) of extracted types.
String (Default: "MAGICSEP").
Stephen R. Martin
A wrapper around strcapture.
Given "a_MAGICSEP_b", returns a vector of "a_" and "_b".
Useful for converting a multiple-parameter string into columns of parameters.
User can give column names in labs, and types of each extracted component as a list in types.
User can customize sep, but by default assumes MAGICSEP.