Coef method for lmmelsm objects.
# S3 method for lmmelsm
coef(object, prob = 0.95, summarize = TRUE, ...)List of summaries (if summarize is TRUE), or list of MCMC samples.
lmmelsm object.
Numeric (Default: .95). Amount of probability mass contained in the credible interval.
Logical (Default: TRUE). Whether to return posterior summaries (TRUE) or MCMC samples (FALSE).
Not used.
Stephen R Martin
Extracts all group-specific coefficients from lmmelsm object.
Note that this is different from ranef.
Whereas ranef extracts the zero-centered random effects, coef extracts the group-specific effects, defined as the sum of the fixed effect and random effect.