Extract model fitted variates.
# S3 method for lmmelsm
fitted(object, prob = 0.95, summarize = TRUE, ...)List of eta and eta_logsd. If summarize is TRUE, then the list contains formatted summary tables. If FALSE, then the list contains MCMC samples for all variables.
lmmelsm object.
Numeric (Default: .95). Amount of probability mass contained in the credible interval.
Logical (Default: TRUE). Whether to return posterior summaries (TRUE) or MCMC samples (FALSE).
Not used.
Stephen Martin
Extracts model fitted variates. When a latent MMELSM, these are the latent score expectations and log standard deviations. When an observed MMELSM, these are the observed score expectations and log standard deviations.