Ranef method for lmmelsm objects.
# S3 method for lmmelsm
ranef(object, prob = 0.95, summarize = TRUE, ...)List of ranef summaries (random_mu_intercept, random_logsd_intercept, random_mu_coef, and random_logsd_coef), or samples (if summarize = FALSE).
lmmelsm object.
Numeric (Default: .95). Amount of probability mass contained in the credible interval.
Logical (Default: TRUE). Whether to return posterior summaries (TRUE) or MCMC samples (FALSE).
Not used.
Stephen R. Martin
Extracts the random effects from the lmmelsm object.
Note that this is different from the random coefficients.
E.g., if \(\beta_{0i} = \beta_0 + u_{0i}\), then coef extracts \(\beta_{0i}\) and ranef extracts \(u_{0i}\).